@@ -2,37 +2,43 @@
 #' @name check_collinearity
 #'
 #' @description
+#' `check_collinearity()` checks regression models for multicollinearity by
+#' calculating the (generalized) variance inflation factor (VIF, Fox & Monette
+#' 1992). `multicollinearity()` is an alias for `check_collinearity()`.
+#' `check_concurvity()` is a wrapper around `mgcv::concurvity()`, and can be
+#' considered as a collinearity check for smooth terms in GAMs. Confidence
+#' intervals for VIF and tolerance are based on Marcoulides et al. (2019,
+#' Appendix B).
 #'
-#'  `check_collinearity()` checks regression models for
-#'  multicollinearity by calculating the variance inflation factor (VIF).
-#'  `multicollinearity()` is an alias for `check_collinearity()`.
-#'  `check_concurvity()` is a wrapper around `mgcv::concurvity()`, and can be
-#'  considered as a collinearity check for smooth terms in GAMs. Confidence
-#'  intervals for VIF and tolerance are based on Marcoulides et al.
-#'  (2019, Appendix B).
-#'
-#' @param x A model object (that should at least respond to `vcov()`,
-#'  and if possible, also to `model.matrix()` - however, it also should
-#'  work without `model.matrix()`).
+#' @param x A model object (that should at least respond to `vcov()`, and if
+#' possible, also to `model.matrix()` - however, it also should work without
+#' `model.matrix()`).
 #' @param component For models with zero-inflation component, multicollinearity
-#'  can be checked for the conditional model (count component,
-#'  `component = "conditional"` or `component = "count"`),
-#'  zero-inflation component (`component = "zero_inflated"` or
-#'  `component = "zi"`) or both components (`component = "all"`).
-#'  Following model-classes are currently supported: `hurdle`,
-#'  `zeroinfl`, `zerocount`, `MixMod` and `glmmTMB`.
+#' can be checked for the conditional model (count component, `component =
+#' "conditional"` or `component = "count"`), zero-inflation component
+#' (`component = "zero_inflated"` or `component = "zi"`) or both components
+#' (`component = "all"`). Following model-classes are currently supported:
+#' `hurdle`, `zeroinfl`, `zerocount`, `MixMod` and `glmmTMB`.
 #' @param ci Confidence Interval (CI) level for VIF and tolerance values.
 #' @param verbose Toggle off warnings or messages.
 #' @param ... Currently not used.
 #'
 #' @return A data frame with information about name of the model term, the
-#'   variance inflation factor and associated confidence intervals, the factor
-#'   by which the standard error is increased due to possible correlation
-#'   with other terms, and tolerance values (including confidence intervals),
-#'   where `tolerance = 1/vif`.
+#' (generalized) variance inflation factor and associated confidence intervals,
+#' the adjusted VIF, which is the factor by which the standard error is
+#' increased due to possible correlation with other terms (inflation due to
+#' collinearity), and tolerance values (including confidence intervals), where
+#' `tolerance = 1/vif`.
 #'
 #' @seealso [`see::plot.see_check_collinearity()`] for options to customize the plot.
 #'
+#' @details
+#' `check_collinearity()` calculates the generalized variance inflation factor
+#' (Fox & Monette 1992), which also returns valid results for categorical
+#' variables. The *adjusted* VIF is calculated as `VIF^(1/(2*<nlevels>)` (Fox &
+#' Monette 1992), which is identical to the square root of the VIF for numeric
+#' predictors, or for categorical variables with two levels.
+#'
 #' @section Multicollinearity:
 #' Multicollinearity should not be confused with a raw strong correlation
 #' between predictors. What matters is the association between one or more
@@ -61,7 +67,7 @@
 #' correlation of that predictor with other predictors. A value between 5 and
 #' 10 indicates a moderate correlation, while VIF values larger than 10 are a
 #' sign for high, not tolerable correlation of model predictors (_James et al.
-#' 2013_). The *Increased SE* column in the output indicates how much larger
+#' 2013_). The *adjusted VIF* column in the output indicates how much larger
 #' the standard error is due to the association with other predictors
 #' conditional on the remaining variables in the model. Note that these
 #' thresholds, although commonly used, are also criticized for being too high.
@@ -73,7 +79,12 @@
 #' This portion of multicollinearity among the component terms of an
 #' interaction is also called "inessential ill-conditioning", which leads to
 #' inflated VIF values that are typically seen for models with interaction
-#' terms _(Francoeur 2013)_.
+#' terms _(Francoeur 2013)_. Centering interaction terms can resolve this
+#' issue _(Kim and Jung 2024)_.
+#'
+#' @section Multicollinearity and Polynomial Terms:
+#' Polynomial transformations are considered a single term and thus VIFs are
+#' not calculated between them.
 #'
 #' @section Concurvity for Smooth Terms in Generalized Additive Models:
 #' `check_concurvity()` is a wrapper around `mgcv::concurvity()`, and can be
@@ -90,27 +101,34 @@
 #'
 #' @references
 #'
-#' - Francoeur, R. B. (2013). Could Sequential Residual Centering Resolve
-#' Low Sensitivity in Moderated Regression? Simulations and Cancer Symptom
-#' Clusters. Open Journal of Statistics, 03(06), 24-44.
+#' - Fox, J., & Monette, G. (1992). Generalized Collinearity Diagnostics.
+#'   Journal of the American Statistical Association, 87(417), 178–183.
 #'
-#' - James, G., Witten, D., Hastie, T., and Tibshirani, R. (eds.). (2013).
-#' An introduction to statistical learning: with applications in R. New York:
-#' Springer.
+#' - Francoeur, R. B. (2013). Could Sequential Residual Centering Resolve
+#'   Low Sensitivity in Moderated Regression? Simulations and Cancer Symptom
+#'   Clusters. Open Journal of Statistics, 03(06), 24-44.
+#'
+#' - James, G., Witten, D., Hastie, T., and Tibshirani, R. (eds.). (2013). An
+#'   introduction to statistical learning: with applications in R. New York:
+#'   Springer.
+#'
+#' - Kim, Y., & Jung, G. (2024). Understanding linear interaction analysis with
+#'   causal graphs. British Journal of Mathematical and Statistical Psychology,
+#'   00, 1–14.
 #'
 #' - Marcoulides, K. M., and Raykov, T. (2019). Evaluation of Variance
-#' Inflation Factors in Regression Models Using Latent Variable Modeling
-#' Methods. Educational and Psychological Measurement, 79(5), 874–882.
+#'   Inflation Factors in Regression Models Using Latent Variable Modeling
+#'   Methods. Educational and Psychological Measurement, 79(5), 874–882.
 #'
 #' - McElreath, R. (2020). Statistical rethinking: A Bayesian course with
-#' examples in R and Stan. 2nd edition. Chapman and Hall/CRC.
+#'   examples in R and Stan. 2nd edition. Chapman and Hall/CRC.
 #'
 #' - Vanhove, J. (2019). Collinearity isn't a disease that needs curing.
-#' [webpage](https://janhove.github.io/posts/2019-09-11-collinearity/)
+#'   [webpage](https://janhove.github.io/posts/2019-09-11-collinearity/)
 #'
 #' - Zuur AF, Ieno EN, Elphick CS. A protocol for data exploration to avoid
-#' common statistical problems: Data exploration. Methods in Ecology and
-#' Evolution (2010) 1:3–14.
+#'   common statistical problems: Data exploration. Methods in Ecology and
+#'   Evolution (2010) 1:3–14.
 #'
 #' @family functions to check model assumptions and and assess model quality
 #'
@@ -124,7 +142,7 @@
 #' m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
 #' check_collinearity(m)
 #'
-#' @examplesIf require("see")
+#' @examplesIf insight::check_if_installed("see", minimum_version = "0.9.1", quietly = TRUE)
 #' # plot results
 #' x <- check_collinearity(m)
 #' plot(x)
@@ -139,7 +157,6 @@ check_collinearity <- function(x, ...) {
 multicollinearity <- check_collinearity
 
 
-
 # default ------------------------------
 
 #' @rdname check_collinearity
@@ -150,7 +167,6 @@ check_collinearity.default <- function(x, ci = 0.95, verbose = TRUE, ...) {
 }
 
 
-
 # methods -------------------------------------------
 
 #' @export
@@ -193,8 +209,8 @@ plot.check_collinearity <- function(x, ...) {
   x <- insight::format_table(x)
   x <- datawizard::data_rename(
     x,
-    pattern = "SE_factor",
-    replacement = "Increased SE",
+    select = "SE_factor",
+    replacement = "adj. VIF",
     verbose = FALSE
   )
 
@@ -218,7 +234,6 @@ plot.check_collinearity <- function(x, ...) {
 }
 
 
-
 # other classes ----------------------------------
 
 #' @export
@@ -294,66 +309,79 @@ check_collinearity.betaor <- check_collinearity.logitor
 check_collinearity.betamfx <- check_collinearity.logitor
 
 
-
 # zi-models -------------------------------------
 
 #' @rdname check_collinearity
 #' @export
 check_collinearity.glmmTMB <- function(x,
-                                       component = c("all", "conditional", "count", "zi", "zero_inflated"),
+                                       component = "all",
                                        ci = 0.95,
                                        verbose = TRUE,
                                        ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
 #' @export
 check_collinearity.MixMod <- function(x,
-                                      component = c("all", "conditional", "count", "zi", "zero_inflated"),
+                                      component = "all",
                                       ci = 0.95,
                                       verbose = TRUE,
                                       ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
 #' @export
 check_collinearity.hurdle <- function(x,
-                                      component = c("all", "conditional", "count", "zi", "zero_inflated"),
+                                      component = "all",
                                       ci = 0.95,
                                       verbose = verbose,
                                       ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
 #' @export
 check_collinearity.zeroinfl <- function(x,
-                                        component = c("all", "conditional", "count", "zi", "zero_inflated"),
+                                        component = "all",
                                         ci = 0.95,
                                         verbose = verbose,
                                         ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
 #' @export
 check_collinearity.zerocount <- function(x,
-                                         component = c("all", "conditional", "count", "zi", "zero_inflated"),
+                                         component = "all",
                                          ci = 0.95,
                                          verbose = verbose,
                                          ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
-
 # utilities ---------------------------------
 
 .check_collinearity_zi_model <- function(x, component, ci = 0.95, verbose = TRUE) {
@@ -403,9 +431,8 @@ check_collinearity.zerocount <- function(x,
 }
 
 
-
 .check_collinearity <- function(x, component, ci = 0.95, verbose = TRUE) {
-  v <- insight::get_varcov(x, component = component, verbose = FALSE)
+  v <- .safe(insight::get_varcov(x, component = component, verbose = FALSE))
 
   # sanity check
   if (is.null(v)) {
@@ -451,7 +478,7 @@ check_collinearity.zerocount <- function(x,
     insight::format_alert("Model has no intercept. VIFs may not be sensible.")
   }
 
-  f <- insight::find_formula(x)
+  f <- insight::find_formula(x, verbose = FALSE)
 
   # hurdle or zeroinfl model can have no zero-inflation formula, in which case
   # we have the same formula as for conditional formula part
@@ -514,16 +541,58 @@ check_collinearity.zerocount <- function(x,
   if (!is.null(insight::find_interactions(x)) && any(result > 10) && isTRUE(verbose)) {
     insight::format_alert(
       "Model has interaction terms. VIFs might be inflated.",
-      "You may check multicollinearity among predictors of a model without interaction terms."
+      "Try to center the variables used for the interaction, or check multicollinearity among predictors of a model without interaction terms." # nolint
     )
   }
 
+  # check if CIs are requested
+  conf_ints <- .vif_ci(x, result, ci)
+
+  out <- insight::text_remove_backticks(
+    data.frame(
+      Term = model_terms,
+      VIF = result,
+      VIF_CI_low = 1 / (1 - conf_ints$CI_low),
+      VIF_CI_high = 1 / (1 - conf_ints$CI_high),
+      SE_factor = .adjusted_vif(x, result, model_terms),
+      Tolerance = 1 / result,
+      Tolerance_CI_low = 1 - conf_ints$CI_high,
+      Tolerance_CI_high = 1 - conf_ints$CI_low,
+      stringsAsFactors = FALSE
+    ),
+    column = "Term"
+  )
+  attr(out, "ci") <- ci
+
+  attr(out, "data") <- insight::text_remove_backticks(
+    data.frame(
+      Term = model_terms,
+      VIF = result,
+      SE_factor = .adjusted_vif(x, result, model_terms),
+      stringsAsFactors = FALSE
+    ),
+    column = "Term"
+  )
+
+  attr(out, "CI") <- data.frame(
+    VIF_CI_low = 1 / (1 - conf_ints$CI_low),
+    VIF_CI_high = 1 / (1 - conf_ints$CI_high),
+    Tolerance_CI_low = 1 - conf_ints$CI_high,
+    Tolerance_CI_high = 1 - conf_ints$CI_low,
+    stringsAsFactors = FALSE
+  )
+
+  class(out) <- c("check_collinearity", "see_check_collinearity", "data.frame")
+  out
+}
+
+
+.vif_ci <- function(x, result, ci) {
   # CIs, see Appendix B 10.1177/0013164418817803
   r <- 1 - (1 / result)
   n <- insight::n_obs(x)
   p <- insight::n_parameters(x)
 
-  # check if CIs are requested
   if (!is.null(ci) && !is.na(ci) && is.numeric(ci)) {
     ci_lvl <- (1 + ci) / 2
 
@@ -537,46 +606,34 @@ check_collinearity.zerocount <- function(x,
   } else {
     ci_lo <- ci_up <- NA
   }
-
-  out <- insight::text_remove_backticks(
-    data.frame(
-      Term = model_terms,
-      VIF = result,
-      VIF_CI_low = 1 / (1 - ci_lo),
-      VIF_CI_high = 1 / (1 - ci_up),
-      SE_factor = sqrt(result),
-      Tolerance = 1 / result,
-      Tolerance_CI_low = 1 - ci_up,
-      Tolerance_CI_high = 1 - ci_lo,
-      stringsAsFactors = FALSE
-    ),
-    column = "Term"
-  )
-  attr(out, "ci") <- ci
-
-  attr(out, "data") <- insight::text_remove_backticks(
-    data.frame(
-      Term = model_terms,
-      VIF = result,
-      SE_factor = sqrt(result),
-      stringsAsFactors = FALSE
-    ),
-    column = "Term"
-  )
-
-  attr(out, "CI") <- data.frame(
-    VIF_CI_low = 1 / (1 - ci_lo),
-    VIF_CI_high = 1 / (1 - ci_up),
-    Tolerance_CI_low = 1 - ci_up,
-    Tolerance_CI_high = 1 - ci_lo,
-    stringsAsFactors = FALSE
-  )
-
-  class(out) <- c("check_collinearity", "see_check_collinearity", "data.frame")
-  out
+  list(CI_low = ci_lo, CI_high = ci_up)
 }
 
 
+.adjusted_vif <- function(x, result, model_terms) {
+  tryCatch(
+    {
+      # get data from model frame, so we know which variables are factors
+      d <- insight::get_data(x, source = "mf", verbose = FALSE)
+      # degrees of freedom per variable - init to 1
+      dof <- rep_len(1, length(model_terms))
+      # find factors, which were converted inside formula. we need to convert
+      # these into real factors now, to determine their number of levels
+      factors <- attributes(d)$factors
+      d[factors] <- lapply(d[factors], as.factor)
+      # add factors from data frame
+      factors <- unique(c(factors, colnames(d)[vapply(d, is.factor, logical(1))]))
+      # find position of factors in model terms
+      pos <- match(factors, insight::clean_names(model_terms))
+      # copy df for factors
+      dof[pos] <- vapply(d[factors], nlevels, numeric(1)) - 1
+      # finally, calculate adjusted vif
+      result^(1 / (2 * dof))
+    },
+    error = function(e) sqrt(result)
+  )
+}
+
 
 .term_assignments <- function(x, component, verbose = TRUE) {
   tryCatch(
@@ -613,7 +670,6 @@ check_collinearity.zerocount <- function(x,
 }
 
 
-
 .find_term_assignment <- function(x, component, verbose = TRUE) {
   pred <- insight::find_predictors(x)[[component]]
 
@@ -648,7 +704,6 @@ check_collinearity.zerocount <- function(x,
 }
 
 
-
 .zi_term_assignment <- function(x, component = "zero_inflated", verbose = TRUE) {
   tryCatch(
     {
