@@ -26,22 +26,23 @@
 #' check_homogeneity(model)
 #'
 #' # plot results
-#' if (require("see")) {
-#'   result <- check_homogeneity(model)
-#'   plot(result)
-#' }
+#' @examplesIf insight::check_if_installed("see", minimum_version = "0.9.1", quietly = TRUE)
+#' result <- check_homogeneity(model)
+#' plot(result)
 #' @export
-check_homogeneity <- function(x, method = c("bartlett", "fligner", "levene", "auto"), ...) {
+check_homogeneity <- function(x, method = "bartlett", ...) {
   UseMethod("check_homogeneity")
 }
 
 
-
 # default -------------------------
 
 #' @export
-check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "levene", "auto"), ...) {
-  method <- match.arg(method)
+check_homogeneity.default <- function(x, method = "bartlett", ...) {
+  method <- insight::validate_argument(
+    method,
+    c("bartlett", "fligner", "levene", "auto")
+  )
 
   resp <- insight::find_response(x)
   pred <- insight::find_predictors(x, component = "conditional", flatten = TRUE)
@@ -105,7 +106,6 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
 }
 
 
-
 # methods -----------------------
 
 #' @export
@@ -130,7 +130,6 @@ plot.check_homogeneity <- function(x, ...) {
 }
 
 
-
 # other classes -----------------------------
 
 #' @rdname check_homogeneity
