@@ -28,6 +28,9 @@
 #' scale. To get back to the original scale, the likelihood of the model is
 #' multiplied by the Jacobian/derivative of the transformation.
 #'
+#' In case it is not possible to return the corrected AIC value, a warning
+#' is given that the corrected log-likelihood value could not be computed.
+#'
 #' @references
 #' - Akaike, H. (1973) Information theory as an extension of the maximum
 #' likelihood principle. In: Second International Symposium on Information
@@ -52,6 +55,13 @@
 #' # performance_aic() correctly detects transformed response and
 #' # returns corrected AIC
 #' performance_aic(model)
+#'
+#' \dontrun{
+#' # there are a few exceptions where the corrected log-likelihood values
+#' # cannot be returned. The following exampe gives a warning.
+#' model <- lm(1 / mpg ~ factor(cyl), mtcars)
+#' performance_aic(model)
+#' }
 #' @export
 performance_aicc <- function(x, ...) {
   UseMethod("performance_aicc")
@@ -130,7 +140,6 @@ performance_aic.vgam <- function(x, ...) {
 performance_aic.vglm <- performance_aic.vgam
 
 
-
 # Survey models --------------------------------------
 
 #' @export
@@ -143,7 +152,6 @@ performance_aic.svyglm <- function(x, ...) {
 performance_aic.svycoxph <- performance_aic.svyglm
 
 
-
 # mfx models --------------------------------------
 
 #' @export
@@ -256,8 +264,6 @@ performance_aicc.rma <- function(x, ...) {
 }
 
 
-
-
 # jacobian / derivate for log models and other transformations ----------------
 
 
@@ -265,68 +271,13 @@ performance_aicc.rma <- function(x, ...) {
 .adjust_ic_jacobian <- function(model, ic) {
   response_transform <- insight::find_transformation(model)
   if (!is.null(ic) && !is.null(response_transform) && !identical(response_transform, "identity")) {
-    adjustment <- .safe(.ll_analytic_adjustment(model, insight::get_weights(model, remove_na = TRUE)))
+    adjustment <- .safe(insight::get_loglikelihood_adjustment(
+      model,
+      insight::get_weights(model, remove_na = TRUE)
+    ))
     if (!is.null(adjustment)) {
       ic <- ic - 2 * adjustment
     }
   }
   ic
 }
-
-
-# copied from `insight`
-.ll_analytic_adjustment <- function(x, model_weights = NULL) {
-  tryCatch(
-    {
-      trans <- insight::find_transformation(x)
-      switch(trans,
-        identity = .weighted_sum(log(insight::get_response(x)), w = model_weights),
-        log = .weighted_sum(log(1 / insight::get_response(x)), w = model_weights),
-        log1p = .weighted_sum(log(1 / (insight::get_response(x) + 1)), w = model_weights),
-        log2 = .weighted_sum(log(1 / (insight::get_response(x) * log(2))), w = model_weights),
-        log10 = .weighted_sum(log(1 / (insight::get_response(x) * log(10))), w = model_weights),
-        exp = .weighted_sum(insight::get_response(x), w = model_weights),
-        expm1 = .weighted_sum((insight::get_response(x) - 1), w = model_weights),
-        sqrt = .weighted_sum(log(0.5 / sqrt(insight::get_response(x))), w = model_weights),
-        .ll_jacobian_adjustment(x, model_weights)
-      )
-    },
-    error = function(e) {
-      NULL
-    }
-  )
-}
-
-
-# this function calculates the adjustment for the log-likelihood of a model
-# with transformed response
-.ll_jacobian_adjustment <- function(model, weights = NULL) {
-  tryCatch(
-    {
-      trans <- insight::get_transformation(model)$transformation
-      .weighted_sum(log(
-        diag(attr(with(
-          insight::get_data(model, verbose = FALSE),
-          stats::numericDeriv(
-            expr = quote(trans(
-              get(insight::find_response(model))
-            )),
-            theta = insight::find_response(model)
-          )
-        ), "gradient"))
-      ), weights)
-    },
-    error = function(e) {
-      NULL
-    }
-  )
-}
-
-
-.weighted_sum <- function(x, w = NULL, ...) {
-  if (is.null(w)) {
-    mean(x) * length(x)
-  } else {
-    stats::weighted.mean(x, w) * length(x)
-  }
-}
