@@ -29,7 +29,6 @@ r2_mcfadden <- function(model, ...) {
 }
 
 
-
 # helper -----------------------
 
 
@@ -49,11 +48,6 @@ r2_mcfadden <- function(model, ...) {
 }
 
 
-
-
-
-
-
 # r2 via loglik and update --------------------------
 
 
@@ -63,15 +57,23 @@ r2_mcfadden.glm <- function(model, verbose = TRUE, ...) {
   if (is.null(info)) {
     info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
   }
+  matrix_response <- grepl("cbind", insight::find_response(model), fixed = TRUE)
 
-  if (info$is_binomial && !info$is_bernoulli && class(model)[1] == "glm") {
+  if (info$is_binomial && !info$is_betabinomial && !info$is_bernoulli && class(model)[1] %in% c("glm", "glmmTMB")) {
     if (verbose) {
       insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
     }
     return(NULL)
   }
+  # currently, beta-binomial models without proportion response are not supported
+  if (info$is_betabinomial && matrix_response) {
+    if (verbose) {
+      insight::format_warning("Can't calculate accurate R2 for beta-binomial models with matrix-response formulation.")
+    }
+    return(NULL)
+  }
 
-  l_null <- insight::get_loglikelihood(stats::update(model, ~1))
+  l_null <- insight::get_loglikelihood(insight::null_model(model))
   .r2_mcfadden(model, l_null)
 }
 
@@ -99,6 +101,9 @@ r2_mcfadden.brmultinom <- r2_mcfadden.glm
 #' @export
 r2_mcfadden.censReg <- r2_mcfadden.glm
 
+#' @export
+r2_mcfadden.glmmTMB <- r2_mcfadden.glm
+
 #' @export
 r2_mcfadden.truncreg <- r2_mcfadden.glm
 
@@ -121,9 +126,6 @@ r2_mcfadden.mblogit <- function(model, ...) {
 }
 
 
-
-
-
 # mfx models ---------------------
 
 
@@ -151,7 +153,6 @@ r2_mcfadden.probitmfx <- r2_mcfadden.logitmfx
 r2_mcfadden.negbinmfx <- r2_mcfadden.logitmfx
 
 
-
 # special models -------------------------------------------
 
 
@@ -161,24 +162,20 @@ r2_mcfadden.vglm <- function(model, ...) {
     insight::format_error("Can't get log-likelihood when `summ` is not zero.")
   }
 
-  l_null <- insight::get_loglikelihood(stats::update(model, ~1))
+  l_null <- insight::get_loglikelihood(insight::null_model(model))
   .r2_mcfadden(model, l_null)
 }
 
 
 #' @export
 r2_mcfadden.clm2 <- function(model, ...) {
-  l_null <- insight::get_loglikelihood(stats::update(model, location = ~1, scale = ~1))
+  l_null <- insight::get_loglikelihood(insight::null_model(model))
   .r2_mcfadden(model, l_null)
 }
 
 
-
 #' @export
-r2_mcfadden.multinom <- function(model, ...) {
-  l_null <- insight::get_loglikelihood(stats::update(model, ~1, trace = FALSE))
-  .r2_mcfadden(model, l_null)
-}
+r2_mcfadden.multinom <- r2_mcfadden.clm2
 
 
 #' @export
