@@ -22,8 +22,6 @@ r2_nagelkerke <- function(model, ...) {
 }
 
 
-
-
 # helper ---------------------------
 
 
@@ -47,9 +45,6 @@ r2_nagelkerke <- function(model, ...) {
 }
 
 
-
-
-
 # Nagelkerke's R2 based on Cox&Snell's R2 ----------------
 
 #' @export
@@ -58,26 +53,64 @@ r2_nagelkerke.glm <- function(model, verbose = TRUE, ...) {
   if (is.null(info)) {
     info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
   }
+
   if (info$is_binomial && !info$is_bernoulli && class(model)[1] == "glm") {
     if (verbose) {
       insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
     }
     return(NULL)
-  } else {
-    r2cox <- r2_coxsnell(model)
-    if (is.na(r2cox) || is.null(r2cox)) {
-      return(NULL)
-    }
-    r2_nagelkerke <- r2cox / (1 - exp(-model$null.deviance / insight::n_obs(model, disaggregate = TRUE)))
-    names(r2_nagelkerke) <- "Nagelkerke's R2"
-    r2_nagelkerke
   }
+
+  r2cox <- r2_coxsnell(model)
+
+  if (is.na(r2cox) || is.null(r2cox)) {
+    return(NULL)
+  }
+
+  r2_nagelkerke <- r2cox / (1 - exp(-model$null.deviance / insight::n_obs(model, disaggregate = TRUE)))
+  names(r2_nagelkerke) <- "Nagelkerke's R2"
+  r2_nagelkerke
 }
 
 #' @export
 r2_nagelkerke.BBreg <- r2_nagelkerke.glm
 
 
+#' @export
+r2_nagelkerke.glmmTMB <- function(model, verbose = TRUE, ...) {
+  info <- list(...)$model_info
+  if (is.null(info)) {
+    info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
+  }
+
+  if (info$is_binomial && !info$is_bernoulli) {
+    if (verbose) {
+      insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
+    }
+    return(NULL)
+  }
+
+  dev <- stats::deviance(model)
+
+  # if no deviance, return NA
+  if (is.null(dev)) {
+    return(NULL)
+  }
+
+  null_mod <- suppressWarnings(insight::null_model(model))
+  null_dev <- stats::deviance(null_mod)
+  r2cox <- (1 - exp((dev - null_dev) / insight::n_obs(model, disaggregate = TRUE)))
+
+  if (is.na(r2cox) || is.null(r2cox)) {
+    return(NULL)
+  }
+
+  r2_nagelkerke <- r2cox / (1 - exp(-null_dev / insight::n_obs(model, disaggregate = TRUE)))
+  names(r2_nagelkerke) <- "Nagelkerke's R2"
+  r2_nagelkerke
+}
+
+
 #' @export
 r2_nagelkerke.nestedLogit <- function(model, ...) {
   n <- insight::n_obs(model, disaggregate = TRUE)
@@ -105,7 +138,6 @@ r2_nagelkerke.bife <- function(model, ...) {
 }
 
 
-
 # mfx models ---------------------
 
 
@@ -133,26 +165,24 @@ r2_nagelkerke.negbinirr <- r2_nagelkerke.logitmfx
 r2_nagelkerke.negbinmfx <- r2_nagelkerke.logitmfx
 
 
-
-
 # Nagelkerke's R2 based on LogLik ----------------
 
 
 #' @export
 r2_nagelkerke.multinom <- function(model, ...) {
-  l_base <- insight::get_loglikelihood(stats::update(model, ~1, trace = FALSE))
+  l_base <- insight::get_loglikelihood(insight::null_model(model))
   .r2_nagelkerke(model, l_base)
 }
 
 #' @export
 r2_nagelkerke.clm2 <- function(model, ...) {
-  l_base <- insight::get_loglikelihood(stats::update(model, location = ~1, scale = ~1))
+  l_base <- insight::get_loglikelihood(insight::null_model(model))
   .r2_nagelkerke(model, l_base)
 }
 
 #' @export
 r2_nagelkerke.clm <- function(model, ...) {
-  l_base <- insight::get_loglikelihood(stats::update(model, ~1))
+  l_base <- insight::get_loglikelihood(insight::null_model(model))
   # if no loglik, return NA
   if (length(as.numeric(l_base)) == 0) {
     return(NULL)
@@ -163,6 +193,9 @@ r2_nagelkerke.clm <- function(model, ...) {
 #' @export
 r2_nagelkerke.polr <- r2_nagelkerke.clm
 
+#' @export
+r2_nagelkerke.serp <- r2_nagelkerke.clm
+
 #' @export
 r2_nagelkerke.cpglm <- r2_nagelkerke.clm
 
@@ -185,7 +218,6 @@ r2_nagelkerke.truncreg <- r2_nagelkerke.clm
 r2_nagelkerke.DirichletRegModel <- r2_coxsnell.clm
 
 
-
 # Nagelkerke's R2 based on LogLik stored in model object ----------------
 
 
