@@ -9,20 +9,26 @@ test_that("check_collinearity, correct order in print", {
       "",
       "Low Correlation",
       "",
-      " Term  VIF    VIF 95% CI Increased SE Tolerance Tolerance 95% CI",
-      " gear 1.53 [1.19,  2.51]         1.24      0.65     [0.40, 0.84]",
+      " Term  VIF    VIF 95% CI adj. VIF Tolerance Tolerance 95% CI",
+      " gear 1.53 [1.19,  2.51]     1.24      0.65     [0.40, 0.84]",
       "",
       "Moderate Correlation",
       "",
-      " Term  VIF    VIF 95% CI Increased SE Tolerance Tolerance 95% CI",
-      "   wt 5.05 [3.21,  8.41]         2.25      0.20     [0.12, 0.31]",
-      "  cyl 5.41 [3.42,  9.04]         2.33      0.18     [0.11, 0.29]",
-      " disp 9.97 [6.08, 16.85]         3.16      0.10     [0.06, 0.16]"
+      " Term  VIF    VIF 95% CI adj. VIF Tolerance Tolerance 95% CI",
+      "   wt 5.05 [3.21,  8.41]     2.25      0.20     [0.12, 0.31]",
+      "  cyl 5.41 [3.42,  9.04]     2.33      0.18     [0.11, 0.29]",
+      " disp 9.97 [6.08, 16.85]     3.16      0.10     [0.06, 0.16]"
     )
   )
 })
 
 
+test_that("check_collinearity, interaction", {
+  m <- lm(mpg ~ wt * cyl, data = mtcars)
+  expect_message(check_collinearity(m), regex = "Model has interaction terms")
+})
+
+
 test_that("check_collinearity", {
   skip_if_not_installed("glmmTMB")
   skip_if_not(getRversion() >= "4.0.0")
@@ -48,7 +54,6 @@ test_that("check_collinearity", {
 })
 
 
-
 test_that("check_collinearity", {
   skip_if_not_installed("glmmTMB")
   skip_if_not(getRversion() >= "4.0.0")
@@ -216,5 +221,41 @@ test_that("check_collinearity, hurdle/zi models w/o zi-formula", {
 test_that("check_collinearity, invalid data", {
   dd <- data.frame(y = as.difftime(0:5, units = "days"))
   m1 <- lm(y ~ 1, data = dd)
-  expect_error(check_collinearity(m1), "Can't extract variance-covariance matrix")
+  expect_message(check_collinearity(m1), "Could not extract the variance-covariance")
+})
+
+test_that("check_collinearity, glmmTMB hurdle w/o zi", {
+  skip_if_not_installed("glmmTMB")
+  data(Salamanders, package = "glmmTMB")
+  mod_trunc_error <- glmmTMB::glmmTMB(
+    count ~ spp + mined + (1 | site),
+    data = Salamanders[Salamanders$count > 0, , drop = FALSE],
+    family = glmmTMB::truncated_nbinom2(),
+    ziformula = ~0,
+    dispformula = ~1
+  )
+  out <- check_collinearity(mod_trunc_error)
+  expect_equal(out$VIF, c(1.03414, 1.03414), tolerance = 1e-3)
+})
+
+test_that("check_collinearity, validate adjusted vif against car", {
+  skip_if_not_installed("car")
+  data(mtcars)
+  mod <- lm(mpg ~ cyl + hp + am, data = mtcars)
+  out1 <- car::vif(mod)
+  out2 <- check_collinearity(mod)
+  expect_equal(out1, out2$VIF, tolerance = 1e-3, ignore_attr = TRUE)
+
+  mod <- lm(mpg ~ as.factor(cyl) + hp + gear, data = mtcars)
+  out1 <- car::vif(mod)
+  out2 <- check_collinearity(mod)
+  expect_equal(out1[, 1], out2$VIF, tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(out1[, 3], out2$SE_factor, tolerance = 1e-3, ignore_attr = TRUE)
+
+  mtcars$gear <- factor(mtcars$gear)
+  mod <- lm(mpg ~ as.factor(cyl) + hp + gear, data = mtcars)
+  out1 <- car::vif(mod)
+  out2 <- check_collinearity(mod)
+  expect_equal(out1[, 1], out2$VIF, tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(out1[, 3], out2$SE_factor, tolerance = 1e-3, ignore_attr = TRUE)
 })
